summaryrefslogtreecommitdiff
path: root/src/ai/api/ai_industry.hpp
diff options
context:
space:
mode:
authoryexo <yexo@openttd.org>2009-02-14 21:09:48 +0000
committeryexo <yexo@openttd.org>2009-02-14 21:09:48 +0000
commitcea470e687a0ce6807d344346540b390ea5cc8f8 (patch)
treedbc9660444b4367aed13fb0a9ba170c5192cb268 /src/ai/api/ai_industry.hpp
parent58359b8d6e411eb43fa362ce364d89bb2a0d71c0 (diff)
downloadopenttd-cea470e687a0ce6807d344346540b390ea5cc8f8.tar.xz
(svn r15485) -Change [API CHANGE]: Split AIIndustry::HasHeliportAndDock and GetHeliportAndDockLocation in HasHeliport/HasDock and GetHeliportLocation/GetDockLocation.
Diffstat (limited to 'src/ai/api/ai_industry.hpp')
-rw-r--r--src/ai/api/ai_industry.hpp31
1 files changed, 24 insertions, 7 deletions
diff --git a/src/ai/api/ai_industry.hpp b/src/ai/api/ai_industry.hpp
index 11d3dbc43..abaff2ea2 100644
--- a/src/ai/api/ai_industry.hpp
+++ b/src/ai/api/ai_industry.hpp
@@ -132,21 +132,38 @@ public:
static bool IsBuiltOnWater(IndustryID industry_id);
/**
- * Does this industry have a heliport and dock?
+ * Does this industry have a heliport?
* @param industry_id The index of the industry.
* @pre IsValidIndustry(industry_id).
- * @return True when the industry has a heliport and dock.
+ * @return True when the industry has a heliport.
*/
- static bool HasHeliportAndDock(IndustryID industry_id);
+ static bool HasHeliport(IndustryID industry_id);
/**
- * Gets the location of the industry's heliport/dock.
+ * Gets the location of the industry's heliport.
* @param industry_id The index of the industry.
* @pre IsValidIndustry(industry_id).
* @pre HasHeliportAndDock(industry_id).
* @return The location of the industry's heliport/dock.
*/
- static TileIndex GetHeliportAndDockLocation(IndustryID industry_id);
+ static TileIndex GetHeliportLocation(IndustryID industry_id);
+
+ /**
+ * Does this industry have a dock?
+ * @param industry_id The index of the industry.
+ * @pre IsValidIndustry(industry_id).
+ * @return True when the industry has a dock.
+ */
+ static bool HasDock(IndustryID industry_id);
+
+ /**
+ * Gets the location of the industry's dock.
+ * @param industry_id The index of the industry.
+ * @pre IsValidIndustry(industry_id).
+ * @pre HasDock(industry_id).
+ * @return The location of the industry's dock.
+ */
+ static TileIndex GetDockLocation(IndustryID industry_id);
/**
* Get the IndustryType of the industry.
@@ -132,21 +132,38 @@ public:
* @param industry_id The index of the industry.
* @pre IsValidIndustry(industry_id).
- * @pre HasHeliportAndDock(industry_id).
- * @return The location of the industry's heliport/dock.
+ * @pre HasHeliport(industry_id).
+ * @return The location of the industry's heliport.
*/